Documentation
¶
Overview ¶
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
This code was autogenerated. Do not edit directly.
- beta.proto *
- No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen) *
- API version: version not set
- Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
Index ¶
- Variables
- func CacheExpires(r *http.Response) time.Time
- type APIClient
- type APIKey
- type APIResponse
- type BasicAuth
- type BetaCounter
- type BetaCounterUpdateRequest
- type BetaList
- type Configuration
- type GenericSwaggerError
- type SDKApiService
- func (a *SDKApiService) AddListValue(ctx context.Context, body SdkAddListValueBody, name string) (BetaList, *http.Response, error)
- func (a *SDKApiService) GetCounter(ctx context.Context, name string) (BetaCounter, *http.Response, error)
- func (a *SDKApiService) GetList(ctx context.Context, name string) (BetaList, *http.Response, error)
- func (a *SDKApiService) RemoveListValue(ctx context.Context, body SdkRemoveListValueBody, name string) (BetaList, *http.Response, error)
- func (a *SDKApiService) UpdateCounter(ctx context.Context, body TheRequestedUpdateToMakeToTheCounter, ...) (BetaCounter, *http.Response, error)
- func (a *SDKApiService) UpdateList(ctx context.Context, body TheListToUpdate, listName string) (BetaList, *http.Response, error)
- type SdkAddListValueBody
- type SdkRemoveListValueBody
- type TheListToUpdate
- type TheRequestedUpdateToMakeToTheCounter
Constants ¶
This section is empty.
Variables ¶
var ( // ContextOAuth2 takes a oauth2.TokenSource as authentication for the request. ContextOAuth2 = contextKey("token") // ContextBasicAuth takes BasicAuth as authentication for the request. ContextBasicAuth = contextKey("basic") // ContextAccessToken takes a string oauth2 access token as authentication for the request. ContextAccessToken = contextKey("accesstoken") // ContextAPIKey takes an APIKey as authentication for the request ContextAPIKey = contextKey("apikey") )
Functions ¶
Types ¶
type APIClient ¶
type APIClient struct {
SDKApi *SDKApiService
// contains filtered or unexported fields
}
APIClient manages communication with the beta.proto API vversion not set In most cases there should be only one, shared, APIClient.
func NewAPIClient ¶
func NewAPIClient(cfg *Configuration) *APIClient
NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.
func (*APIClient) ChangeBasePath ¶
Change base path to allow switching to mocks
type APIKey ¶
APIKey provides API key based authentication to a request passed via context using ContextAPIKey
type APIResponse ¶
type APIResponse struct {
*http.Response `json:"-"`
Message string `json:"message,omitempty"`
// Operation is the name of the swagger operation.
Operation string `json:"operation,omitempty"`
// RequestURL is the request URL. This value is always available, even if the
// embedded *http.Response is nil.
RequestURL string `json:"url,omitempty"`
// Method is the HTTP method used for the request. This value is always
// available, even if the embedded *http.Response is nil.
Method string `json:"method,omitempty"`
// Payload holds the contents of the response body (which may be nil or empty).
// This is provided here as the raw response.Body() reader will have already
// been drained.
Payload []byte `json:"-"`
}
func NewAPIResponse ¶
func NewAPIResponse(r *http.Response) *APIResponse
func NewAPIResponseWithError ¶
func NewAPIResponseWithError(errorMessage string) *APIResponse
type BasicAuth ¶
type BasicAuth struct {
UserName string `json:"userName,omitempty"`
Password string `json:"password,omitempty"`
}
BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth
type BetaCounter ¶
type BetaCounter struct {
Name string `json:"name,omitempty"`
Count string `json:"count,omitempty"`
Capacity string `json:"capacity,omitempty"`
}
A representation of a Counter.
type BetaCounterUpdateRequest ¶
type BetaCounterUpdateRequest struct {
Name string `json:"name,omitempty"`
Count string `json:"count,omitempty"`
Capacity string `json:"capacity,omitempty"`
CountDiff string `json:"countDiff,omitempty"`
}
A representation of a Counter Update Request.
type BetaList ¶
type BetaList struct {
Name string `json:"name,omitempty"`
Capacity string `json:"capacity,omitempty"`
Values []string `json:"values,omitempty"`
}
A representation of a List.
type Configuration ¶
type Configuration struct {
BasePath string `json:"basePath,omitempty"`
Host string `json:"host,omitempty"`
Scheme string `json:"scheme,omitempty"`
DefaultHeader map[string]string `json:"defaultHeader,omitempty"`
UserAgent string `json:"userAgent,omitempty"`
HTTPClient *http.Client
}
func NewConfiguration ¶
func NewConfiguration() *Configuration
func (*Configuration) AddDefaultHeader ¶
func (c *Configuration) AddDefaultHeader(key string, value string)
type GenericSwaggerError ¶
type GenericSwaggerError struct {
// contains filtered or unexported fields
}
GenericSwaggerError Provides access to the body, error and model on returned errors.
func (GenericSwaggerError) Body ¶
func (e GenericSwaggerError) Body() []byte
Body returns the raw bytes of the response
func (GenericSwaggerError) Error ¶
func (e GenericSwaggerError) Error() string
Error returns non-empty string if there was an error.
func (GenericSwaggerError) Model ¶
func (e GenericSwaggerError) Model() interface{}
Model returns the unpacked model of the error
type SDKApiService ¶
type SDKApiService service
func (*SDKApiService) AddListValue ¶
func (a *SDKApiService) AddListValue(ctx context.Context, body SdkAddListValueBody, name string) (BetaList, *http.Response, error)
SDKApiService Adds a value to a List and returns updated List. Returns NOT_FOUND if the List does not exist. Returns ALREADY_EXISTS if the value is already in the List. Returns OUT_OF_RANGE if the List is already at Capacity.
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param body
- @param name The name of the List to add a value to.
@return BetaList
func (*SDKApiService) GetCounter ¶
func (a *SDKApiService) GetCounter(ctx context.Context, name string) (BetaCounter, *http.Response, error)
SDKApiService Gets a Counter. Returns NOT_FOUND if the Counter does not exist.
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param name The name of the Counter to get
@return BetaCounter
func (*SDKApiService) GetList ¶
SDKApiService Gets a List. Returns NOT_FOUND if the List does not exist.
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param name The name of the List to get
@return BetaList
func (*SDKApiService) RemoveListValue ¶
func (a *SDKApiService) RemoveListValue(ctx context.Context, body SdkRemoveListValueBody, name string) (BetaList, *http.Response, error)
SDKApiService Removes a value from a List and returns updated List. Returns NOT_FOUND if the List does not exist. Returns NOT_FOUND if the value is not in the List.
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param body
- @param name The name of the List to remove a value from.
@return BetaList
func (*SDKApiService) UpdateCounter ¶
func (a *SDKApiService) UpdateCounter(ctx context.Context, body TheRequestedUpdateToMakeToTheCounter, counterUpdateRequestName string) (BetaCounter, *http.Response, error)
SDKApiService UpdateCounter returns the updated Counter. Returns NOT_FOUND if the Counter does not exist (name cannot be updated). Returns OUT_OF_RANGE if the Count is out of range [0,Capacity].
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param body The requested update to make to the Counter
- @param counterUpdateRequestName The name of the Counter to update
@return BetaCounter
func (*SDKApiService) UpdateList ¶
func (a *SDKApiService) UpdateList(ctx context.Context, body TheListToUpdate, listName string) (BetaList, *http.Response, error)
SDKApiService UpdateList returns the updated List. Returns NOT_FOUND if the List does not exist (name cannot be updated). **THIS WILL OVERWRITE ALL EXISTING LIST.VALUES WITH ANY REQUEST LIST.VALUES** Use AddListValue() or RemoveListValue() for modifying the List.Values field. Returns INVALID_ARGUMENT if the field mask path(s) are not field(s) of the List. If a field mask path(s) is specified, but the value is not set in the request List object, then the default value for the variable will be set (i.e. 0 for \"capacity\", empty list for \"values\").
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param body The List to update
- @param listName The name of the List
@return BetaList
type SdkAddListValueBody ¶ added in v1.44.0
type SdkAddListValueBody struct {
Value string `json:"value"`
}
type SdkRemoveListValueBody ¶ added in v1.44.0
type SdkRemoveListValueBody struct {
Value string `json:"value"`
}